{% load rest_framework %}

<!-- Modal -->
<div class="modal fade auth-modal auth-basic" id="auth_basic_modal" tabindex="-1" role="dialog" aria-labelledby="basic authentication modal">
<div class="modal-dialog modal-md" role="document">
  <div class="modal-content">
    <div class="modal-header">
      <h3 class="modal-title"><i class="fa fa-key"></i> Basic Authentication</h3>
    </div>

    <form class="form-horizontal authentication-basic-form">
    <div class="modal-body">
      <div class="form-group">
        <label for="authorization" class="col-sm-2 control-label">Username:</label>

        <div class="col-sm-10">
          <input type="text" class="form-control" id="username" required>
        </div>
      </div>

      <div class="form-group">
        <label for="authorization" class="col-sm-2 control-label">Password:</label>

        <div class="col-sm-10">
          <input type="password" class="form-control" id="password" required>
        </div>
      </div>
    </div>

    <div class="modal-footer">
      <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
      <button type="submit" class="btn btn-primary">Use Basic Authentication</button>
    </div>
    </form>

  </div>
</div>
</div>
