{% load i18n %}
<h2>{% trans "Search" %}</h2>
<form class="form-inline">
  <div class="form-group">
    <div class="input-group">
      <input type="text" class="form-control" style="width: 350px" name="{{ param }}" value="{{ term }}">
      <span class="input-group-btn">
        <button class="btn btn-default" type="submit"><span class="glyphicon glyphicon-search" aria-hidden="true"></span> {% trans "Search" %}</button>
      </span>
    </div>
  </div>
</form>
