# coding=utf-8
def saludar():
    print("Hola, te estoy saludando desde la función saludar() del módulo saludos")


class Saludo:
    def __init__(self):
        print("Hola, te estoy saludando desde el __init__ de la clase Saludo")


def despedir():
    print("Adiós, me estoy despidiendo desde la función despedir() del módulo despedidas")


class Despedida:
    def __init__(self):
        print("Adiós, me estoy despidiendo desde el __init__ de la clase Despedida")
